@@ -1,6 +1,7 @@
 import logging
 from copy import deepcopy
 from functools import wraps
+from io import BytesIO
 from pathlib import Path
 from threading import Lock as ThreadLock
 from typing import (
@@ -15,8 +16,10 @@ from typing import (
     TYPE_CHECKING,
     Tuple,
     TypeVar,
+    Union,
 )
 
+from aiofiles.tempfile import SpooledTemporaryFile
 from aiohttp.typedefs import (
     LooseHeaders,
     StrOrURL,
@@ -123,7 +126,8 @@ class PixivClient(Net):
             proxy=proxy,
             trust_env=trust_env
         )
-        with open(Path(__file__) / "../config", encoding='utf-8') as file:
+        config_path = (Path(__file__) / "../config").resolve()
+        with open(config_path, encoding='utf-8') as file:
             self._config = PixivClient.Config(
                 *ArkoWrapper(file.readlines()).map(lambda x: x.strip())
             )
@@ -132,6 +136,7 @@ class PixivClient(Net):
             'App-OS-Version': '12.2',
             'App-Version': '7.6.2',
             'user-agent': self._config.user_agent,
+            'Referer': 'https://app-api.pixiv.net/'
         }
         PixivClient._instances.append(self)
 
@@ -278,3 +283,26 @@ class PixivClient(Net):
             return await self.login_with_token(token)
         else:
             return await self.login_with_pwd(username, password)
+
+    async def download(
+            self, url: StrOrURL, *,
+            output: Optional[Union[str, Path, BytesIO]] = None
+    ) -> Optional[bytes]:
+        if output is None:
+            out = True
+            output = BytesIO()
+        else:
+            out = False
+            output = Path(output).resolve().open('wb+')
+        content = (await self.get(url)).content
+        async with SpooledTemporaryFile(mode='wb+') as file:
+            # noinspection PyProtectedMember
+            file._file._file = output
+            while True:
+                data, is_end = await content.readchunk()
+                await file.write(data)
+                if is_end or not data:
+                    break
+            await file.seek(0)
+            if out:
+                return await file.read()
