@@ -14,6 +14,7 @@ from pydantic import (
     HttpUrl,
     validator,
 )
+from yarl import URL
 
 from async_pixiv.model._base import PixivModel
 from async_pixiv.model.other import ImageUrl
@@ -48,6 +49,7 @@ class ArtWorkType(Enum):
     illust = 'illust'
     ugoira = 'ugoira'
     manga = 'manga'
+    novel = 'novel'
 
 
 # noinspection PyProtectedMember
@@ -56,6 +58,9 @@ class ArtWork(PixivModel):
         id: int
         title: str
 
+    class MetaPage(PixivModel):
+        image_urls: "ImageUrl"
+
     id: int
     title: str
     type: ArtWorkType
@@ -73,7 +78,7 @@ class ArtWork(PixivModel):
     x_restrict: int
     series: Optional[Series]
     meta_single_page: Dict[str, HttpUrl]
-    meta_pages: List["ImageUrl"]
+    meta_pages: List[MetaPage]
     total_view: int
     total_bookmarks: int
     is_bookmarked: bool
@@ -88,6 +93,19 @@ class ArtWork(PixivModel):
             return self.tags[0].name.title().replace('-', '') == 'R18'
         return False
 
+    @property
+    def link(self) -> URL:
+        return URL(f"https://www.pixiv.net/artworks/{self.id}")
+
+    @property
+    def all_image_urls(self) -> List[URL]:
+        result = []
+        for page in self.meta_pages:
+            result.append(URL(str(
+                page.image_urls.original or page.image_urls.large
+            )))
+        return result
+
     async def detail(
             self, client: Optional["PixivClient"] = None, *,
             for_ios: bool = True
